Module update

Module update 

Update plugin metadata in the marketplace.

Re-reads plugin.json from disk to refresh the marketplace entry, and optionally bumps the plugin version.

Functions

update_plugins
Updates the named plugins in the marketplace by re-reading their plugin.json from disk.